@@ -3,11 +3,26 @@ from math import erf, exp, log, pi, sqrt
 from typing import Dict
 
 
-class BlackScholesBase(ABC):
+class StandardNormalMixin:
+    """
+    Fast PDF and CDF calculations for standard normal distribution.
+    """
+
+    @staticmethod
+    def _pdf(x: float) -> float:
+        """PDF of standard normal distribution."""
+        return exp(-(x**2) / 2.0) / sqrt(2.0 * pi)
+
+    @staticmethod
+    def _cdf(x):
+        """CDF of standard normal distribution."""
+        return (1.0 + erf(x / sqrt(2.0))) / 2.0
+
+
+class BlackScholesBase(ABC, StandardNormalMixin):
     """
     Base functionality to calculate (European) prices
-    and Greeks with the Black-Scholes-Merton formula
-    (without dividends).
+    and Greeks with the Black-Scholes-Merton formula.
 
     :param S: Price of underlying asset \n
     :param K: Strike price \n
@@ -27,7 +42,7 @@ class BlackScholesBase(ABC):
 
     @abstractmethod
     def price(self) -> float:
-        """Price for option."""
+        """Fair value for option."""
         ...
 
     @abstractmethod
@@ -43,12 +58,12 @@ class BlackScholesBase(ABC):
 
     @abstractmethod
     def dual_delta(self) -> float:
+        """1st derivative of option price with respect to the strike price."""
         ...
 
     def gamma(self) -> float:
         """
         Rate of change in delta with respect to the underlying stock price (2nd derivative).
-        NOTE: Gamma is the same for calls and puts.
         """
         return (
             exp(-self.q * self.T)
@@ -57,6 +72,9 @@ class BlackScholesBase(ABC):
         )
 
     def dual_gamma(self) -> float:
+        """
+        Rate of change in delta with respect to the strike price (2nd derivative).
+        """
         return (
             exp(-self.r * self.T)
             * self._pdf(self._d2)
@@ -66,8 +84,6 @@ class BlackScholesBase(ABC):
     def vega(self) -> float:
         """
         Rate of change in option price with respect to the volatility of the asset.
-
-        NOTE: Vega is the same for calls and puts.
         """
         return self.S * self._pdf(self._d1) * sqrt(self.T)
 
@@ -99,7 +115,7 @@ class BlackScholesBase(ABC):
         return self.delta() * self.S / self.price()
 
     def vanna(self) -> float:
-        """Sensitivity of delta with respect to change in vol."""
+        """Sensitivity of delta with respect to change in volatility."""
         return -self._pdf(self._d1) * self._d2 / self.sigma
 
     @abstractmethod
@@ -108,7 +124,7 @@ class BlackScholesBase(ABC):
         ...
 
     def vomma(self) -> float:
-        """2nd order sensitivity to vol."""
+        """2nd order sensitivity to volatility."""
         return self.vega() * self._d1 * self._d2 / self.sigma
 
     def veta(self) -> float:
@@ -121,42 +137,48 @@ class BlackScholesBase(ABC):
             * (
                 self.q
                 + (self.r - self.q) * self._d1 / (self.sigma * sqrt(self.T))
-                - (1 + self._d1 * self._d2) / (2 * self.T)
+                - (1.0 + self._d1 * self._d2) / (2.0 * self.T)
             )
         )
 
     def phi(self) -> float:
+        """2nd order partial derivative with respect to strike price. \n
+        Phi is used in the Breeden-Litzenberger formula. \n
+        Breeden-Litzenberger uses quoted option prices
+        to estimate risk-neutral probabilities.
+        """
         sigma2 = self.sigma**2
         exp_factor = (
-            -1
-            / (2 * sigma2 * self.T)
+            -1.0
+            / (2.0 * sigma2 * self.T)
             * (log(self.K / self.S) - ((self.r - self.q) - 0.5 * sigma2) * self.T) ** 2
         )
         return (
             exp(-self.r * self.T)
-            * (1 / self.K)
-            * (1 / sqrt(2 * pi * sigma2 * self.T))
+            * (1.0 / self.K)
+            * (1.0 / sqrt(2.0 * pi * sigma2 * self.T))
             * exp(exp_factor)
         )
 
     def speed(self) -> float:
-        return -self.gamma() / self.S * (self._d1 / (self.sigma * sqrt(self.T)) + 1)
+        """Rate of change in Gamma with respect to change in the underlying price."""
+        return -self.gamma() / self.S * (self._d1 / (self.sigma * sqrt(self.T)) + 1.0)
 
     def zomma(self) -> float:
-        """Rate of change of gamma with respect to changes in vol."""
-        return self.gamma() * ((self._d1 * self._d2 - 1) / self.sigma)
+        """Rate of change of gamma with respect to changes in volatility."""
+        return self.gamma() * ((self._d1 * self._d2 - 1.0) / self.sigma)
 
     def color(self) -> float:
         """Rate of change of gamma over time."""
         return (
             -exp(-self.q * self.T)
             * self._pdf(self._d1)
-            / (2 * self.S * self.T * self.sigma * sqrt(self.T))
+            / (2.0 * self.S * self.T * self.sigma * sqrt(self.T))
             * (
-                2 * self.q * self.T
-                + 1
+                2.0 * self.q * self.T
+                + 1.0
                 + (
-                    2 * (self.r - self.q) * self.T
+                    2.0 * (self.r - self.q) * self.T
                     - self._d2 * self.sigma * sqrt(self.T)
                 )
                 / (self.sigma * sqrt(self.T))
@@ -172,7 +194,7 @@ class BlackScholesBase(ABC):
         return (
             -self.vega()
             / self.sigma**2
-            * (d1d2 * (1 - d1d2) + self._d1**2 + self._d2**2)
+            * (d1d2 * (1.0 - d1d2) + self._d1**2 + self._d2**2)
         )
 
     def get_core_greeks(self) -> Dict[str, float]:
@@ -199,7 +221,8 @@ class BlackScholesBase(ABC):
         return {"naive_itm": self.in_the_money(), "dual_delta": self.dual_delta()}
 
     def get_all_greeks(self) -> Dict[str, float]:
-        """Retrieve all Greeks implemented as a dictionary."""
+        """Retrieve all Greeks for the Black-Scholes-Merton model
+        implemented as a dictionary."""
         return {
             "delta": self.delta(),
             "gamma": self.gamma(),
@@ -224,8 +247,8 @@ class BlackScholesBase(ABC):
     @property
     def _d1(self) -> float:
         """1st probability factor that acts as a multiplication factor for stock prices."""
-        return (1 / (self.sigma * sqrt(self.T))) * (
-            log(self.S / self.K) + (self.r + self.sigma**2 / 2) * self.T
+        return (1.0 / (self.sigma * sqrt(self.T))) * (
+            log(self.S / self.K) + (self.r - self.q + 0.5 * self.sigma**2) * self.T
         )
 
     @property
@@ -233,12 +256,116 @@ class BlackScholesBase(ABC):
         """2nd probability parameter that acts as a multiplication factor for discounting."""
         return self._d1 - self.sigma * sqrt(self.T)
 
-    @staticmethod
-    def _pdf(x: float) -> float:
-        """PDF of standard normal distribution."""
-        return exp(-(x**2) / 2) / sqrt(2 * pi)
 
-    @staticmethod
-    def _cdf(x):
-        """CDF of standard normal distribution."""
-        return (1.0 + erf(x / sqrt(2.0))) / 2.0
+class Black76Base(ABC, StandardNormalMixin):
+    """
+    Base functionality to calculate (European) prices
+    and Greeks with the Black-76 formula. \n
+    This variant of the Black-Scholes-Merton model is
+    often used for pricing options on futures and bonds.
+
+    :param F: Futures price \n
+    :param K: Strike price \n
+    :param T: Time till expiration in years (1/12 indicates 1 month) \n
+    :param r: Risk-free interest rate (0.05 indicates 5%) \n
+    :param sigma: Volatility (standard deviation) of stock (0.15 indicates 15%) \n
+    """
+
+    def __init__(self, F: float, K: float, T: float, r: float, sigma: float):
+        # Some parameters must be positive
+        for param in [F, K, T, sigma]:
+            assert (
+                param >= 0.0
+            ), f"Some parameters cannot be negative. Got '{param}' as an argument."
+        self.F, self.K, self.T, self.r, self.sigma = F, K, T, r, sigma
+
+    @abstractmethod
+    def price(self):
+        """Fair value for option."""
+        ...
+
+    @abstractmethod
+    def delta(self):
+        """Rate of change in option price
+        with respect to the futures price (1st derivative)."""
+        ...
+
+    def gamma(self) -> float:
+        """
+        Rate of change in delta with respect to the underlying stock price (2nd derivative).
+        """
+        return (
+            exp(-self.r * self.T)
+            * self._pdf(self._d1)
+            / (self.F * self.sigma * sqrt(self.T))
+        )
+
+    def vega(self) -> float:
+        """Rate of change in option price with respect to the volatility
+        of underlying futures contract.
+        """
+        return self.F * exp(-self.r * self.T) * self._pdf(self._d1) * sqrt(self.T)
+
+    @abstractmethod
+    def theta(self) -> float:
+        """
+        Rate of change in option price
+        with respect to time (i.e. time decay).
+        """
+        ...
+
+    @abstractmethod
+    def rho(self) -> float:
+        """Rate of change in option price
+        with respect to the risk-free rate.
+        """
+        ...
+
+    def vanna(self) -> float:
+        """Sensitivity of delta with respect to change in volatility."""
+        return self.vega() / self.F * (1 - self._d1 / (self.sigma * sqrt(self.T)))
+
+    def vomma(self) -> float:
+        """2nd order sensitivity to volatility."""
+        return self.vega() * self._d1 * self._d2 / self.sigma
+
+    def get_core_greeks(self) -> Dict[str, float]:
+        """
+        Get the top 5 most well known Greeks.
+        1. Delta
+        2. Gamma
+        3. Vega
+        4. Theta
+        5. Rho
+        """
+        return {
+            "delta": self.delta(),
+            "gamma": self.gamma(),
+            "vega": self.vega(),
+            "theta": self.theta(),
+            "rho": self.rho(),
+        }
+
+    def get_all_greeks(self) -> Dict[str, float]:
+        """Retrieve all Greeks for the Black76 model implemented as a dictionary."""
+        return {
+            "delta": self.delta(),
+            "gamma": self.gamma(),
+            "vega": self.vega(),
+            "theta": self.theta(),
+            "rho": self.rho(),
+            "vanna": self.vanna(),
+            "vomma": self.vomma(),
+        }
+
+    @property
+    def _d1(self) -> float:
+        """1st probability factor that acts as a multiplication factor for futures contracts."""
+        return (log(self.F / self.K) + 0.5 * self.sigma**2 * self.T) / (
+            self.sigma * sqrt(self.T)
+        )
+
+    @property
+    def _d2(self) -> float:
+        """2nd probability parameter that acts as a multiplication factor for discounting."""
+        return self._d1 - self.sigma * sqrt(self.T)
